# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main_window.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1211, 684)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/siviIcon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setTabShape(QtWidgets.QTabWidget.Triangular)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.tabWidget_2 = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget_2.setStyleSheet("")
        self.tabWidget_2.setObjectName("tabWidget_2")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.tab_2)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.filename = QtWidgets.QLabel(self.tab_2)
        self.filename.setObjectName("filename")
        self.horizontalLayout.addWidget(self.filename)
        self.btn_file = QtWidgets.QPushButton(self.tab_2)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/load.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_file.setIcon(icon1)
        self.btn_file.setObjectName("btn_file")
        self.horizontalLayout.addWidget(self.btn_file)
        self.btn_reload = QtWidgets.QPushButton(self.tab_2)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/reload.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_reload.setIcon(icon2)
        self.btn_reload.setObjectName("btn_reload")
        self.horizontalLayout.addWidget(self.btn_reload)
        self.btn_close = QtWidgets.QPushButton(self.tab_2)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("rc/close.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_close.setIcon(icon3)
        self.btn_close.setObjectName("btn_close")
        self.horizontalLayout.addWidget(self.btn_close)
        self.verticalLayout_9.addLayout(self.horizontalLayout)
        self.widget = QtWidgets.QWidget(self.tab_2)
        self.widget.setObjectName("widget")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.redraw = QtWidgets.QPushButton(self.widget)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/writing.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.redraw.setIcon(icon4)
        self.redraw.setObjectName("redraw")
        self.horizontalLayout_3.addWidget(self.redraw)
        self.btn_preprocessor = QtWidgets.QPushButton(self.widget)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/work.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_preprocessor.setIcon(icon5)
        self.btn_preprocessor.setObjectName("btn_preprocessor")
        self.horizontalLayout_3.addWidget(self.btn_preprocessor)
        self.btn_save_as = QtWidgets.QPushButton(self.widget)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_save_as.setIcon(icon6)
        self.btn_save_as.setObjectName("btn_save_as")
        self.horizontalLayout_3.addWidget(self.btn_save_as)
        self.btn_save_file = QtWidgets.QPushButton(self.widget)
        self.btn_save_file.setIcon(icon6)
        self.btn_save_file.setObjectName("btn_save_file")
        self.horizontalLayout_3.addWidget(self.btn_save_file)
        self.verticalLayout_9.addWidget(self.widget)
        self.widget_2 = QtWidgets.QWidget(self.tab_2)
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.groupBox_5 = QtWidgets.QGroupBox(self.widget_2)
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_5)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formLayout_4 = QtWidgets.QFormLayout()
        self.formLayout_4.setObjectName("formLayout_4")
        self.afficherLesAxesLabel = QtWidgets.QLabel(self.groupBox_5)
        self.afficherLesAxesLabel.setObjectName("afficherLesAxesLabel")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.afficherLesAxesLabel)
        self.display_axis = QtWidgets.QCheckBox(self.groupBox_5)
        self.display_axis.setObjectName("display_axis")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.display_axis)
        self.afficherLesTapesLabel = QtWidgets.QLabel(self.groupBox_5)
        self.afficherLesTapesLabel.setObjectName("afficherLesTapesLabel")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.afficherLesTapesLabel)
        self.display_draw_steps = QtWidgets.QCheckBox(self.groupBox_5)
        self.display_draw_steps.setObjectName("display_draw_steps")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.display_draw_steps)
        self.afficherLaBoTeDeDLimitationLabel = QtWidgets.QLabel(self.groupBox_5)
        self.afficherLaBoTeDeDLimitationLabel.setObjectName("afficherLaBoTeDeDLimitationLabel")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.afficherLaBoTeDeDLimitationLabel)
        self.display_bounding_box = QtWidgets.QCheckBox(self.groupBox_5)
        self.display_bounding_box.setObjectName("display_bounding_box")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.display_bounding_box)
        self.inverserLAxeXLabel = QtWidgets.QLabel(self.groupBox_5)
        self.inverserLAxeXLabel.setObjectName("inverserLAxeXLabel")
        self.formLayout_4.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.inverserLAxeXLabel)
        self.reverse_display_x = QtWidgets.QCheckBox(self.groupBox_5)
        self.reverse_display_x.setObjectName("reverse_display_x")
        self.formLayout_4.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.reverse_display_x)
        self.inverserLAxeYLabel = QtWidgets.QLabel(self.groupBox_5)
        self.inverserLAxeYLabel.setObjectName("inverserLAxeYLabel")
        self.formLayout_4.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.inverserLAxeYLabel)
        self.reverse_display_y = QtWidgets.QCheckBox(self.groupBox_5)
        self.reverse_display_y.setChecked(True)
        self.reverse_display_y.setObjectName("reverse_display_y")
        self.formLayout_4.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.reverse_display_y)
        self.inverserLAxeZLabel = QtWidgets.QLabel(self.groupBox_5)
        self.inverserLAxeZLabel.setObjectName("inverserLAxeZLabel")
        self.formLayout_4.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.inverserLAxeZLabel)
        self.reverse_display_z = QtWidgets.QCheckBox(self.groupBox_5)
        self.reverse_display_z.setObjectName("reverse_display_z")
        self.formLayout_4.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.reverse_display_z)
        self.verticalLayout.addLayout(self.formLayout_4)
        self.line = QtWidgets.QFrame(self.groupBox_5)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout.addWidget(self.line)
        self.formLayout_5 = QtWidgets.QFormLayout()
        self.formLayout_5.setObjectName("formLayout_5")
        self.label_5 = QtWidgets.QLabel(self.groupBox_5)
        self.label_5.setObjectName("label_5")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.space_x = QtWidgets.QLCDNumber(self.groupBox_5)
        self.space_x.setStyleSheet("color:DarkOrange;")
        self.space_x.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.space_x.setProperty("value", 0.0)
        self.space_x.setObjectName("space_x")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.space_x)
        self.label_11 = QtWidgets.QLabel(self.groupBox_5)
        self.label_11.setObjectName("label_11")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.space_y = QtWidgets.QLCDNumber(self.groupBox_5)
        self.space_y.setStyleSheet("color:DarkOrange;")
        self.space_y.setLineWidth(1)
        self.space_y.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.space_y.setObjectName("space_y")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.space_y)
        self.label_12 = QtWidgets.QLabel(self.groupBox_5)
        self.label_12.setObjectName("label_12")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_12)
        self.space_z = QtWidgets.QLCDNumber(self.groupBox_5)
        self.space_z.setStyleSheet("color:DarkOrange;")
        self.space_z.setSmallDecimalPoint(False)
        self.space_z.setSegmentStyle(QtWidgets.QLCDNumber.Flat)
        self.space_z.setObjectName("space_z")
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.space_z)
        self.verticalLayout.addLayout(self.formLayout_5)
        self.horizontalLayout_5.addWidget(self.groupBox_5)
        self.fileview = QtWidgets.QGraphicsView(self.widget_2)
        self.fileview.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.fileview.setDragMode(QtWidgets.QGraphicsView.ScrollHandDrag)
        self.fileview.setObjectName("fileview")
        self.horizontalLayout_5.addWidget(self.fileview)
        self.code_edit = QtWidgets.QTextEdit(self.widget_2)
        self.code_edit.setObjectName("code_edit")
        self.horizontalLayout_5.addWidget(self.code_edit)
        self.verticalLayout_9.addWidget(self.widget_2)
        self.tabWidget_2.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tab_3)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.groupBox = QtWidgets.QGroupBox(self.tab_3)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.serial_monitor = QtWidgets.QTextEdit(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.serial_monitor.sizePolicy().hasHeightForWidth())
        self.serial_monitor.setSizePolicy(sizePolicy)
        self.serial_monitor.setMinimumSize(QtCore.QSize(0, 300))
        self.serial_monitor.setMaximumSize(QtCore.QSize(16777215, 2000))
        self.serial_monitor.setStyleSheet("background-color:black;")
        self.serial_monitor.setReadOnly(True)
        self.serial_monitor.setObjectName("serial_monitor")
        self.verticalLayout_2.addWidget(self.serial_monitor)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_4.addWidget(self.label_4)
        self.command_edit = QtWidgets.QLineEdit(self.groupBox)
        self.command_edit.setObjectName("command_edit")
        self.horizontalLayout_4.addWidget(self.command_edit)
        self.btn_command = QtWidgets.QPushButton(self.groupBox)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/run.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_command.setIcon(icon7)
        self.btn_command.setObjectName("btn_command")
        self.horizontalLayout_4.addWidget(self.btn_command)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.btn_send_current_file = QtWidgets.QPushButton(self.groupBox)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/upload.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_send_current_file.setIcon(icon8)
        self.btn_send_current_file.setObjectName("btn_send_current_file")
        self.verticalLayout_2.addWidget(self.btn_send_current_file)
        self.sending_progress = QtWidgets.QProgressBar(self.groupBox)
        self.sending_progress.setProperty("value", 0)
        self.sending_progress.setObjectName("sending_progress")
        self.verticalLayout_2.addWidget(self.sending_progress)
        self.gridLayout_3.addWidget(self.groupBox, 1, 0, 1, 1)
        self.tabWidget = QtWidgets.QTabWidget(self.tab_3)
        self.tabWidget.setEnabled(True)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_command = QtWidgets.QWidget()
        self.tab_command.setObjectName("tab_command")
        self.gridLayout = QtWidgets.QGridLayout(self.tab_command)
        self.gridLayout.setObjectName("gridLayout")
        self.grp_cmd = QtWidgets.QGroupBox(self.tab_command)
        self.grp_cmd.setObjectName("grp_cmd")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.grp_cmd)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.btn_x_plus = QtWidgets.QPushButton(self.grp_cmd)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/right.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_x_plus.setIcon(icon9)
        self.btn_x_plus.setObjectName("btn_x_plus")
        self.gridLayout_2.addWidget(self.btn_x_plus, 1, 2, 1, 1)
        self.btn_y_plus = QtWidgets.QPushButton(self.grp_cmd)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/up.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_y_plus.setIcon(icon10)
        self.btn_y_plus.setObjectName("btn_y_plus")
        self.gridLayout_2.addWidget(self.btn_y_plus, 0, 1, 1, 1)
        self.btn_z_plus = QtWidgets.QPushButton(self.grp_cmd)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/up.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.btn_z_plus.setIcon(icon11)
        self.btn_z_plus.setObjectName("btn_z_plus")
        self.gridLayout_2.addWidget(self.btn_z_plus, 0, 3, 1, 1)
        self.btn_z_minus = QtWidgets.QPushButton(self.grp_cmd)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/down.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.btn_z_minus.setIcon(icon12)
        self.btn_z_minus.setObjectName("btn_z_minus")
        self.gridLayout_2.addWidget(self.btn_z_minus, 2, 3, 1, 1)
        self.btn_y_minus = QtWidgets.QPushButton(self.grp_cmd)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/down.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_y_minus.setIcon(icon13)
        self.btn_y_minus.setObjectName("btn_y_minus")
        self.gridLayout_2.addWidget(self.btn_y_minus, 2, 1, 1, 1)
        self.btn_x_minus = QtWidgets.QPushButton(self.grp_cmd)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/left.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_x_minus.setIcon(icon14)
        self.btn_x_minus.setObjectName("btn_x_minus")
        self.gridLayout_2.addWidget(self.btn_x_minus, 1, 0, 1, 1)
        self.btn_go_to_zero = QtWidgets.QPushButton(self.grp_cmd)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/origin.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_go_to_zero.setIcon(icon15)
        self.btn_go_to_zero.setIconSize(QtCore.QSize(64, 64))
        self.btn_go_to_zero.setFlat(False)
        self.btn_go_to_zero.setObjectName("btn_go_to_zero")
        self.gridLayout_2.addWidget(self.btn_go_to_zero, 1, 1, 1, 1)
        self.verticalLayout_6.addLayout(self.gridLayout_2)
        self.gridLayout.addWidget(self.grp_cmd, 1, 0, 1, 1)
        self.grp_auto = QtWidgets.QGroupBox(self.tab_command)
        self.grp_auto.setObjectName("grp_auto")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.grp_auto)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.label_6 = QtWidgets.QLabel(self.grp_auto)
        self.label_6.setWordWrap(True)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_14.addWidget(self.label_6)
        self.auto_cmd_1 = QtWidgets.QWidget(self.grp_auto)
        self.auto_cmd_1.setObjectName("auto_cmd_1")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.auto_cmd_1)
        self.horizontalLayout_10.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label_7 = QtWidgets.QLabel(self.auto_cmd_1)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_10.addWidget(self.label_7)
        self.auto_cmd_axis = QtWidgets.QComboBox(self.auto_cmd_1)
        self.auto_cmd_axis.setObjectName("auto_cmd_axis")
        self.auto_cmd_axis.addItem("")
        self.auto_cmd_axis.addItem("")
        self.auto_cmd_axis.addItem("")
        self.horizontalLayout_10.addWidget(self.auto_cmd_axis)
        self.label_8 = QtWidgets.QLabel(self.auto_cmd_1)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_10.addWidget(self.label_8)
        self.auto_cmd_number = QtWidgets.QSpinBox(self.auto_cmd_1)
        self.auto_cmd_number.setProperty("value", 1)
        self.auto_cmd_number.setObjectName("auto_cmd_number")
        self.horizontalLayout_10.addWidget(self.auto_cmd_number)
        self.auto_cmd_type = QtWidgets.QComboBox(self.auto_cmd_1)
        self.auto_cmd_type.setObjectName("auto_cmd_type")
        self.auto_cmd_type.addItem("")
        self.auto_cmd_type.addItem("")
        self.horizontalLayout_10.addWidget(self.auto_cmd_type)
        self.label_9 = QtWidgets.QLabel(self.auto_cmd_1)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_10.addWidget(self.label_9)
        self.auto_cmd_step = QtWidgets.QSpinBox(self.auto_cmd_1)
        self.auto_cmd_step.setMinimum(-1000)
        self.auto_cmd_step.setMaximum(1000)
        self.auto_cmd_step.setObjectName("auto_cmd_step")
        self.horizontalLayout_10.addWidget(self.auto_cmd_step)
        self.label_10 = QtWidgets.QLabel(self.auto_cmd_1)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_10.addWidget(self.label_10)
        self.verticalLayout_14.addWidget(self.auto_cmd_1)
        self.auto_cmd_2 = QtWidgets.QWidget(self.grp_auto)
        self.auto_cmd_2.setObjectName("auto_cmd_2")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.auto_cmd_2)
        self.horizontalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_13 = QtWidgets.QLabel(self.auto_cmd_2)
        self.label_13.setTextFormat(QtCore.Qt.PlainText)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_6.addWidget(self.label_13)
        self.auto_cmd_axis_2 = QtWidgets.QComboBox(self.auto_cmd_2)
        self.auto_cmd_axis_2.setObjectName("auto_cmd_axis_2")
        self.auto_cmd_axis_2.addItem("")
        self.auto_cmd_axis_2.addItem("")
        self.auto_cmd_axis_2.addItem("")
        self.horizontalLayout_6.addWidget(self.auto_cmd_axis_2)
        self.label_14 = QtWidgets.QLabel(self.auto_cmd_2)
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_6.addWidget(self.label_14)
        self.auto_cmd_step_2 = QtWidgets.QSpinBox(self.auto_cmd_2)
        self.auto_cmd_step_2.setMinimum(-1000)
        self.auto_cmd_step_2.setMaximum(1000)
        self.auto_cmd_step_2.setObjectName("auto_cmd_step_2")
        self.horizontalLayout_6.addWidget(self.auto_cmd_step_2)
        self.label_15 = QtWidgets.QLabel(self.auto_cmd_2)
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_6.addWidget(self.label_15)
        self.verticalLayout_14.addWidget(self.auto_cmd_2)
        self.btn_run_auto_cmd = QtWidgets.QPushButton(self.grp_auto)
        self.btn_run_auto_cmd.setIcon(icon7)
        self.btn_run_auto_cmd.setObjectName("btn_run_auto_cmd")
        self.verticalLayout_14.addWidget(self.btn_run_auto_cmd)
        self.gridLayout.addWidget(self.grp_auto, 2, 0, 1, 1)
        self.groupBox_6 = QtWidgets.QGroupBox(self.tab_command)
        self.groupBox_6.setObjectName("groupBox_6")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.groupBox_6)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.label_16 = QtWidgets.QLabel(self.groupBox_6)
        self.label_16.setWordWrap(True)
        self.label_16.setObjectName("label_16")
        self.verticalLayout_5.addWidget(self.label_16)
        self.widget_4 = QtWidgets.QWidget(self.groupBox_6)
        self.widget_4.setObjectName("widget_4")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.widget_4)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_17 = QtWidgets.QLabel(self.widget_4)
        self.label_17.setObjectName("label_17")
        self.horizontalLayout_7.addWidget(self.label_17)
        self.custom_cmd_number = QtWidgets.QSpinBox(self.widget_4)
        self.custom_cmd_number.setMinimum(1)
        self.custom_cmd_number.setMaximum(1000)
        self.custom_cmd_number.setObjectName("custom_cmd_number")
        self.horizontalLayout_7.addWidget(self.custom_cmd_number)
        self.label_18 = QtWidgets.QLabel(self.widget_4)
        self.label_18.setObjectName("label_18")
        self.horizontalLayout_7.addWidget(self.label_18)
        self.verticalLayout_5.addWidget(self.widget_4)
        self.custom_cmd = QtWidgets.QTextEdit(self.groupBox_6)
        self.custom_cmd.setObjectName("custom_cmd")
        self.verticalLayout_5.addWidget(self.custom_cmd)
        self.btn_run_custom_cmd = QtWidgets.QPushButton(self.groupBox_6)
        self.btn_run_custom_cmd.setIcon(icon7)
        self.btn_run_custom_cmd.setObjectName("btn_run_custom_cmd")
        self.verticalLayout_5.addWidget(self.btn_run_custom_cmd)
        self.gridLayout.addWidget(self.groupBox_6, 1, 1, 2, 1)
        self.btn_set_origin = QtWidgets.QPushButton(self.tab_command)
        self.btn_set_origin.setIcon(icon15)
        self.btn_set_origin.setObjectName("btn_set_origin")
        self.gridLayout.addWidget(self.btn_set_origin, 0, 0, 1, 2)
        self.tabWidget.addTab(self.tab_command, "")
        self.tab_config = QtWidgets.QWidget()
        self.tab_config.setObjectName("tab_config")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.tab_config)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_3 = QtWidgets.QLabel(self.tab_config)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_9.addWidget(self.label_3)
        self.config_list = QtWidgets.QComboBox(self.tab_config)
        self.config_list.setObjectName("config_list")
        self.config_list.addItem("")
        self.horizontalLayout_9.addWidget(self.config_list)
        self.verticalLayout_11.addLayout(self.horizontalLayout_9)
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab_config)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setObjectName("groupBox_3")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBox_3)
        self.formLayout_2.setObjectName("formLayout_2")
        self.modeDePilotageLabel_2 = QtWidgets.QLabel(self.groupBox_3)
        self.modeDePilotageLabel_2.setObjectName("modeDePilotageLabel_2")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.modeDePilotageLabel_2)
        self.drive_y = QtWidgets.QComboBox(self.groupBox_3)
        self.drive_y.setObjectName("drive_y")
        self.drive_y.addItem("")
        self.drive_y.addItem("")
        self.drive_y.addItem("")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.drive_y)
        self.ratioLabel_2 = QtWidgets.QLabel(self.groupBox_3)
        self.ratioLabel_2.setObjectName("ratioLabel_2")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.ratioLabel_2)
        self.ratio_y = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.ratio_y.setObjectName("ratio_y")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.ratio_y)
        self.jeuLabel_2 = QtWidgets.QLabel(self.groupBox_3)
        self.jeuLabel_2.setObjectName("jeuLabel_2")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.jeuLabel_2)
        self.play_y = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.play_y.setObjectName("play_y")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.play_y)
        self.inverserLAxeLabel_2 = QtWidgets.QLabel(self.groupBox_3)
        self.inverserLAxeLabel_2.setObjectName("inverserLAxeLabel_2")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.inverserLAxeLabel_2)
        self.reverse_y = QtWidgets.QCheckBox(self.groupBox_3)
        self.reverse_y.setObjectName("reverse_y")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.reverse_y)
        self.gridLayout_4.addWidget(self.groupBox_3, 0, 1, 1, 1)
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab_config)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setObjectName("groupBox_2")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox_2)
        self.formLayout.setObjectName("formLayout")
        self.modeDePilotageLabel = QtWidgets.QLabel(self.groupBox_2)
        self.modeDePilotageLabel.setObjectName("modeDePilotageLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.modeDePilotageLabel)
        self.drive_x = QtWidgets.QComboBox(self.groupBox_2)
        self.drive_x.setObjectName("drive_x")
        self.drive_x.addItem("")
        self.drive_x.addItem("")
        self.drive_x.addItem("")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.drive_x)
        self.ratioLabel = QtWidgets.QLabel(self.groupBox_2)
        self.ratioLabel.setObjectName("ratioLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.ratioLabel)
        self.ratio_x = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.ratio_x.setObjectName("ratio_x")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.ratio_x)
        self.jeuLabel = QtWidgets.QLabel(self.groupBox_2)
        self.jeuLabel.setObjectName("jeuLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.jeuLabel)
        self.play_x = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        self.play_x.setObjectName("play_x")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.play_x)
        self.inverserLAxeLabel = QtWidgets.QLabel(self.groupBox_2)
        self.inverserLAxeLabel.setObjectName("inverserLAxeLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.inverserLAxeLabel)
        self.reverse_x = QtWidgets.QCheckBox(self.groupBox_2)
        self.reverse_x.setObjectName("reverse_x")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.reverse_x)
        self.gridLayout_4.addWidget(self.groupBox_2, 0, 0, 1, 1)
        self.verticalLayout_12 = QtWidgets.QVBoxLayout()
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.btn_send_config = QtWidgets.QPushButton(self.tab_config)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap("../sivi_cnc_driver/rc/connect.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_send_config.setIcon(icon16)
        self.btn_send_config.setObjectName("btn_send_config")
        self.verticalLayout_12.addWidget(self.btn_send_config)
        self.btn_save_config = QtWidgets.QPushButton(self.tab_config)
        self.btn_save_config.setIcon(icon6)
        self.btn_save_config.setObjectName("btn_save_config")
        self.verticalLayout_12.addWidget(self.btn_save_config)
        self.btn_save_config_as = QtWidgets.QPushButton(self.tab_config)
        self.btn_save_config_as.setIcon(icon6)
        self.btn_save_config_as.setObjectName("btn_save_config_as")
        self.verticalLayout_12.addWidget(self.btn_save_config_as)
        self.gridLayout_4.addLayout(self.verticalLayout_12, 1, 1, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_config)
        self.groupBox_4.setObjectName("groupBox_4")
        self.formLayout_3 = QtWidgets.QFormLayout(self.groupBox_4)
        self.formLayout_3.setObjectName("formLayout_3")
        self.modeDePilotageLabel_3 = QtWidgets.QLabel(self.groupBox_4)
        self.modeDePilotageLabel_3.setObjectName("modeDePilotageLabel_3")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.modeDePilotageLabel_3)
        self.drive_z = QtWidgets.QComboBox(self.groupBox_4)
        self.drive_z.setObjectName("drive_z")
        self.drive_z.addItem("")
        self.drive_z.addItem("")
        self.drive_z.addItem("")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.drive_z)
        self.ratioLabel_3 = QtWidgets.QLabel(self.groupBox_4)
        self.ratioLabel_3.setObjectName("ratioLabel_3")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.ratioLabel_3)
        self.ratio_z = QtWidgets.QDoubleSpinBox(self.groupBox_4)
        self.ratio_z.setObjectName("ratio_z")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.ratio_z)
        self.jeuLabel_3 = QtWidgets.QLabel(self.groupBox_4)
        self.jeuLabel_3.setObjectName("jeuLabel_3")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.jeuLabel_3)
        self.play_z = QtWidgets.QDoubleSpinBox(self.groupBox_4)
        self.play_z.setObjectName("play_z")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.play_z)
        self.inverserLAxeLabel_3 = QtWidgets.QLabel(self.groupBox_4)
        self.inverserLAxeLabel_3.setObjectName("inverserLAxeLabel_3")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.inverserLAxeLabel_3)
        self.reverse_z = QtWidgets.QCheckBox(self.groupBox_4)
        self.reverse_z.setObjectName("reverse_z")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.reverse_z)
        self.gridLayout_4.addWidget(self.groupBox_4, 1, 0, 1, 1)
        self.verticalLayout_11.addLayout(self.gridLayout_4)
        self.tabWidget.addTab(self.tab_config, "")
        self.gridLayout_3.addWidget(self.tabWidget, 1, 1, 1, 1)
        self.groupBox_7 = QtWidgets.QGroupBox(self.tab_3)
        self.groupBox_7.setTitle("")
        self.groupBox_7.setObjectName("groupBox_7")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.groupBox_7)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_19 = QtWidgets.QLabel(self.groupBox_7)
        self.label_19.setObjectName("label_19")
        self.horizontalLayout_2.addWidget(self.label_19)
        self.chk_fake_serial = QtWidgets.QCheckBox(self.groupBox_7)
        self.chk_fake_serial.setObjectName("chk_fake_serial")
        self.horizontalLayout_2.addWidget(self.chk_fake_serial)
        self.line_2 = QtWidgets.QFrame(self.groupBox_7)
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_2.addWidget(self.line_2)
        self.btn_serial_ports_list = QtWidgets.QPushButton(self.groupBox_7)
        self.btn_serial_ports_list.setIcon(icon2)
        self.btn_serial_ports_list.setObjectName("btn_serial_ports_list")
        self.horizontalLayout_2.addWidget(self.btn_serial_ports_list)
        self.line_3 = QtWidgets.QFrame(self.groupBox_7)
        self.line_3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.horizontalLayout_2.addWidget(self.line_3)
        self.label_20 = QtWidgets.QLabel(self.groupBox_7)
        self.label_20.setObjectName("label_20")
        self.horizontalLayout_2.addWidget(self.label_20)
        self.baudrate = QtWidgets.QComboBox(self.groupBox_7)
        self.baudrate.setObjectName("baudrate")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.baudrate.addItem("")
        self.horizontalLayout_2.addWidget(self.baudrate)
        self.label_21 = QtWidgets.QLabel(self.groupBox_7)
        self.label_21.setObjectName("label_21")
        self.horizontalLayout_2.addWidget(self.label_21)
        self.serial_ports_list = QtWidgets.QComboBox(self.groupBox_7)
        self.serial_ports_list.setObjectName("serial_ports_list")
        self.horizontalLayout_2.addWidget(self.serial_ports_list)
        self.btn_connect = QtWidgets.QPushButton(self.groupBox_7)
        self.btn_connect.setIcon(icon16)
        self.btn_connect.setObjectName("btn_connect")
        self.horizontalLayout_2.addWidget(self.btn_connect)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.gridLayout_3.addWidget(self.groupBox_7, 0, 0, 1, 2)
        self.tabWidget_2.addTab(self.tab_3, "")
        self.verticalLayout_4.addWidget(self.tabWidget_2)
        self.widget_5 = QtWidgets.QWidget(self.centralwidget)
        self.widget_5.setObjectName("widget_5")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.widget_5)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_2 = QtWidgets.QLabel(self.widget_5)
        self.label_2.setTextFormat(QtCore.Qt.RichText)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_8.addWidget(self.label_2)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem1)
        self.btn_license = QtWidgets.QPushButton(self.widget_5)
        self.btn_license.setObjectName("btn_license")
        self.horizontalLayout_8.addWidget(self.btn_license)
        self.btn_about_qt = QtWidgets.QPushButton(self.widget_5)
        self.btn_about_qt.setObjectName("btn_about_qt")
        self.horizontalLayout_8.addWidget(self.btn_about_qt)
        self.label_2.raise_()
        self.btn_license.raise_()
        self.btn_about_qt.raise_()
        self.verticalLayout_4.addWidget(self.widget_5)
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.tabWidget_2.setCurrentIndex(0)
        self.tabWidget.setCurrentIndex(0)
        self.baudrate.setCurrentIndex(4)
        self.command_edit.returnPressed.connect(self.btn_command.click)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "SiviCNCDriver"))
        self.filename.setText(_translate("MainWindow", "Pas de fichier"))
        self.btn_file.setText(_translate("MainWindow", "Choisir le fichier"))
        self.btn_reload.setText(_translate("MainWindow", "Recharger"))
        self.btn_close.setText(_translate("MainWindow", "Fermer"))
        self.redraw.setText(_translate("MainWindow", "Redessiner"))
        self.btn_preprocessor.setText(_translate("MainWindow", "Utiliser le préprocesseur sur le fichier"))
        self.btn_save_as.setText(_translate("MainWindow", "Enregister sous..."))
        self.btn_save_file.setText(_translate("MainWindow", "Enregistrer"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Affichage"))
        self.afficherLesAxesLabel.setText(_translate("MainWindow", "Afficher les axes"))
        self.afficherLesTapesLabel.setText(_translate("MainWindow", "Afficher les étapes"))
        self.afficherLaBoTeDeDLimitationLabel.setText(_translate("MainWindow", "Afficher la boîte de délimitation"))
        self.inverserLAxeXLabel.setText(_translate("MainWindow", "Retourner l\'axe X"))
        self.inverserLAxeYLabel.setText(_translate("MainWindow", "Retourner l\'axe Y"))
        self.inverserLAxeZLabel.setText(_translate("MainWindow", "Retourner l\'axe Z"))
        self.label_5.setText(_translate("MainWindow", "Développement selon X"))
        self.label_11.setText(_translate("MainWindow", "Développement selon Y"))
        self.label_12.setText(_translate("MainWindow", "Développement selon Z"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_2), _translate("MainWindow", "Fichier"))
        self.groupBox.setTitle(_translate("MainWindow", "Moniteur série"))
        self.serial_monitor.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Noto Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'Ubuntu\'; font-size:11pt;\"><br /></p></body></html>"))
        self.label_4.setText(_translate("MainWindow", "Commande :"))
        self.btn_command.setText(_translate("MainWindow", "Envoyer"))
        self.btn_send_current_file.setText(_translate("MainWindow", "Envoyer le fichier courrant"))
        self.grp_cmd.setTitle(_translate("MainWindow", "Commande manuelle"))
        self.btn_x_plus.setText(_translate("MainWindow", "X+"))
        self.btn_y_plus.setText(_translate("MainWindow", "Y+"))
        self.btn_z_plus.setText(_translate("MainWindow", "Z+"))
        self.btn_z_minus.setText(_translate("MainWindow", "Z-"))
        self.btn_y_minus.setText(_translate("MainWindow", "Y-"))
        self.btn_x_minus.setText(_translate("MainWindow", "X-"))
        self.btn_go_to_zero.setText(_translate("MainWindow", "Aller à la position\n"
"Zéro"))
        self.grp_auto.setTitle(_translate("MainWindow", "Commandes automatiques"))
        self.label_6.setText(_translate("MainWindow", "Les commandes automatiques permettent d\'envoyer des commandes directement en pas afin de régler la machine."))
        self.label_7.setText(_translate("MainWindow", "L\'axe"))
        self.auto_cmd_axis.setItemText(0, _translate("MainWindow", "X"))
        self.auto_cmd_axis.setItemText(1, _translate("MainWindow", "Y"))
        self.auto_cmd_axis.setItemText(2, _translate("MainWindow", "Z"))
        self.label_8.setText(_translate("MainWindow", "effectue"))
        self.auto_cmd_type.setItemText(0, _translate("MainWindow", "aller"))
        self.auto_cmd_type.setItemText(1, _translate("MainWindow", "aller(s)-retour(s)"))
        self.label_9.setText(_translate("MainWindow", "de"))
        self.label_10.setText(_translate("MainWindow", "pas."))
        self.label_13.setText(_translate("MainWindow", "Entre chaque étape, l\'axe"))
        self.auto_cmd_axis_2.setItemText(0, _translate("MainWindow", "X"))
        self.auto_cmd_axis_2.setItemText(1, _translate("MainWindow", "Y"))
        self.auto_cmd_axis_2.setItemText(2, _translate("MainWindow", "Z"))
        self.label_14.setText(_translate("MainWindow", "se déplace de"))
        self.label_15.setText(_translate("MainWindow", "pas."))
        self.btn_run_auto_cmd.setText(_translate("MainWindow", "Envoyer"))
        self.groupBox_6.setTitle(_translate("MainWindow", "Commandes personnalisées"))
        self.label_16.setText(_translate("MainWindow", "Les commandes personnalisées permettent d\'envoyer des commandes définies par l\'utilisateur un certain nombre de fois afin de régler la machine."))
        self.label_17.setText(_translate("MainWindow", "Répéter"))
        self.label_18.setText(_translate("MainWindow", "fois les commandes :"))
        self.btn_run_custom_cmd.setText(_translate("MainWindow", "Envoyer"))
        self.btn_set_origin.setText(_translate("MainWindow", "Définir l\'origine"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_command), _translate("MainWindow", "Commande"))
        self.label_3.setText(_translate("MainWindow", "Configuration :"))
        self.config_list.setItemText(0, _translate("MainWindow", "Nouvelle configuration"))
        self.groupBox_3.setTitle(_translate("MainWindow", "Axe Y"))
        self.modeDePilotageLabel_2.setText(_translate("MainWindow", "Mode de pilotage"))
        self.drive_y.setItemText(0, _translate("MainWindow", "Normal"))
        self.drive_y.setItemText(1, _translate("MainWindow", "Couple maximal"))
        self.drive_y.setItemText(2, _translate("MainWindow", "Demi pas"))
        self.ratioLabel_2.setText(_translate("MainWindow", "Ratio"))
        self.ratio_y.setSuffix(_translate("MainWindow", " mm/pas"))
        self.jeuLabel_2.setText(_translate("MainWindow", "Jeu"))
        self.play_y.setSuffix(_translate("MainWindow", "  mm"))
        self.inverserLAxeLabel_2.setText(_translate("MainWindow", "Inverser l\'axe"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Axe X"))
        self.modeDePilotageLabel.setText(_translate("MainWindow", "Mode de pilotage"))
        self.drive_x.setItemText(0, _translate("MainWindow", "Normal"))
        self.drive_x.setItemText(1, _translate("MainWindow", "Couple maximal"))
        self.drive_x.setItemText(2, _translate("MainWindow", "Demi pas"))
        self.ratioLabel.setText(_translate("MainWindow", "Ratio"))
        self.ratio_x.setSuffix(_translate("MainWindow", " mm/pas"))
        self.jeuLabel.setText(_translate("MainWindow", "Jeu"))
        self.play_x.setSuffix(_translate("MainWindow", " mm"))
        self.inverserLAxeLabel.setText(_translate("MainWindow", "Inverser l\'axe"))
        self.btn_send_config.setText(_translate("MainWindow", "Envoyer la configuration"))
        self.btn_save_config.setText(_translate("MainWindow", "Enregister"))
        self.btn_save_config_as.setText(_translate("MainWindow", "Enregister sous"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Axe Z"))
        self.modeDePilotageLabel_3.setText(_translate("MainWindow", "Mode de pilotage"))
        self.drive_z.setItemText(0, _translate("MainWindow", "Normal"))
        self.drive_z.setItemText(1, _translate("MainWindow", "Couple maximal"))
        self.drive_z.setItemText(2, _translate("MainWindow", "Demi pas"))
        self.ratioLabel_3.setText(_translate("MainWindow", "Ratio"))
        self.ratio_z.setSuffix(_translate("MainWindow", " mm/pas"))
        self.jeuLabel_3.setText(_translate("MainWindow", "Jeu"))
        self.play_z.setSuffix(_translate("MainWindow", " mm"))
        self.inverserLAxeLabel_3.setText(_translate("MainWindow", "Inverser l\'axe"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_config), _translate("MainWindow", "Configuration"))
        self.label_19.setText(_translate("MainWindow", "Émuler un port série "))
        self.btn_serial_ports_list.setText(_translate("MainWindow", "Lister les ports série"))
        self.label_20.setText(_translate("MainWindow", "Baudrate"))
        self.baudrate.setItemText(0, _translate("MainWindow", "300"))
        self.baudrate.setItemText(1, _translate("MainWindow", "1200"))
        self.baudrate.setItemText(2, _translate("MainWindow", "2400"))
        self.baudrate.setItemText(3, _translate("MainWindow", "4800"))
        self.baudrate.setItemText(4, _translate("MainWindow", "9600"))
        self.baudrate.setItemText(5, _translate("MainWindow", "19200"))
        self.baudrate.setItemText(6, _translate("MainWindow", "38400"))
        self.baudrate.setItemText(7, _translate("MainWindow", "57600"))
        self.baudrate.setItemText(8, _translate("MainWindow", "115200"))
        self.baudrate.setItemText(9, _translate("MainWindow", "230400"))
        self.baudrate.setItemText(10, _translate("MainWindow", "250000"))
        self.label_21.setText(_translate("MainWindow", "Port série"))
        self.btn_connect.setText(_translate("MainWindow", "Connecter"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_3), _translate("MainWindow", "Port Série"))
        self.label_2.setText(_translate("MainWindow", "<html><head/><body><p>SiviCNCDriver est un logiciel développé par klafyvel. Pour plus d\'informations voir <a href=\"http://sivigik.com\"><span style=\" text-decoration: underline; color:#4c6b8a;\">sivigik.com</span></a> .</p></body></html>"))
        self.btn_license.setText(_translate("MainWindow", "Licence"))
        self.btn_about_qt.setText(_translate("MainWindow", "À propos de Qt"))

