"""
The SiviCNCDriver Package
=========================

This is the SiviCNCDriver package. To run the application directly you should
use the ``sivicnc`` command in a shell. Alternately you can use the ``main``
function of the package which doesn't take any parameter.



:Example:

>>> from sivicncdriver.app import main
>>> main()

"""

__version__ = "0.1.2"
